@@ -16,6 +16,7 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
+#include <qglobal.h>
 #include <QtGui/QApplication>
 #include <QtCore/QTranslator>
 #include <QtCore/QLibraryInfo>
@@ -79,6 +80,11 @@ int main(int argc, char *argv[])
     Settings::settings();
 
     MainWindow w;
+
+#ifdef Q_WS_S60
+    w.showMaximized();
+#else
     w.show();
+#endif
     return app.exec();
 }
