@@ -23,9 +23,9 @@
 #include "besancon_p.h"
 
 StationsPluginBesancon::StationsPluginBesancon(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateBesancon();
+  d = new StationsPluginSimplePrivateBesancon();
 }
 
 StationsPluginBesancon::~StationsPluginBesancon()
