@@ -23,9 +23,9 @@
 #include "mulhouse_p.h"
 
 StationsPluginMulhouse::StationsPluginMulhouse(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateMulhouse();
+  d = new StationsPluginSimplePrivateMulhouse();
 }
 
 StationsPluginMulhouse::~StationsPluginMulhouse()
