@@ -30,15 +30,13 @@ StationsPluginFactoryIreland::id() const
 QString
 StationsPluginFactoryIreland::name() const
 {
-  return QString::fromUtf8("Irish Networks - Authors:"
-			   "Patrick Installé <PatrickInstalle@P-Installe.be>,"
-			   "Corentin Chary <corentin.chary@gmail.com>");
+  return QString::fromUtf8("Irish Networks");
 }
 
 QIcon
 StationsPluginFactoryIreland::icon() const
 {
-  return QIcon(":/ireland/bike.png");
+  return QIcon(":/ireland/ir.png");
 }
 
 QList < StationsPlugin * >
