@@ -23,9 +23,9 @@
 #include "luxembourg_p.h"
 
 StationsPluginLuxembourg::StationsPluginLuxembourg(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateLuxembourg();
+  d = new StationsPluginSimplePrivateLuxembourg();
 }
 
 StationsPluginLuxembourg::~StationsPluginLuxembourg()
