@@ -23,9 +23,9 @@
 #include "seville_p.h"
 
 StationsPluginSeville::StationsPluginSeville(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateSeville();
+  d = new StationsPluginSimplePrivateSeville();
 }
 
 StationsPluginSeville::~StationsPluginSeville()
@@ -42,7 +42,7 @@ StationsPluginSeville::id() const
 QString
 StationsPluginSeville::name() const
 {
-  return QString::fromUtf8("Seville");
+  return QString::fromUtf8("Séville");
 }
 
 QString
